@@ -32,19 +32,16 @@ from breezy.plugins.debian.cmds import cmd_builddeb
 from breezy.plugins.debian.directory import (
     source_package_vcs,
     vcs_field_to_bzr_url_converters,
-    )
+)
 
 from breezy.tree import Tree
 from breezy.urlutils import InvalidURL
 from breezy.workingtree import WorkingTree
 
-from breezy.plugins.debian.changelog import (
-    changelog_commit_message,
-    )
 from breezy.plugins.debian.builder import BuildFailedError
 from breezy.plugins.debian.upstream import (
     MissingUpstreamTarball,
-    )
+)
 
 from lintian_brush.detect_gbp_dch import guess_update_changelog
 from lintian_brush.changelog import add_changelog_entry
@@ -52,33 +49,35 @@ from lintian_brush.changelog import add_changelog_entry
 from .. import proposal as _mod_proposal
 from ..utils import (
     open_branch,
-    )
+)
 
 
 __all__ = [
-    'add_changelog_entry',
-    'changelog_add_line',
-    'apt_get_source_package',
-    'guess_update_changelog',
-    'source_package_vcs',
-    'build',
-    'BuildFailedError',
-    'MissingUpstreamTarball',
-    'vcs_field_to_bzr_url_converters',
-    ]
+    "add_changelog_entry",
+    "changelog_add_line",
+    "apt_get_source_package",
+    "guess_update_changelog",
+    "source_package_vcs",
+    "build",
+    "BuildFailedError",
+    "MissingUpstreamTarball",
+    "vcs_field_to_bzr_url_converters",
+]
 
 
-DEFAULT_BUILDER = 'sbuild --no-clean-source'
+DEFAULT_BUILDER = "sbuild --no-clean-source"
 
 
 class NoSuchPackage(Exception):
     """No such package."""
 
 
-def build(tree: Tree,
-          subpath: str = '',
-          builder: Optional[str] = None,
-          result_dir: Optional[str] = None) -> None:
+def build(
+    tree: Tree,
+    subpath: str = "",
+    builder: Optional[str] = None,
+    result_dir: Optional[str] = None,
+) -> None:
     """Build a debian package in a directory.
 
     Args:
@@ -92,8 +91,7 @@ def build(tree: Tree,
     # TODO(jelmer): Refactor brz-debian so it's not necessary
     # to call out to cmd_builddeb, but to lower-level
     # functions instead.
-    cmd_builddeb().run(
-        [tree.abspath(subpath)], builder=builder, result_dir=result_dir)
+    cmd_builddeb().run([tree.abspath(subpath)], builder=builder, result_dir=result_dir)
 
 
 class NoAptSources(Exception):
@@ -109,13 +107,13 @@ def apt_get_source_package(name: str) -> Deb822:
       A `Deb822` object
     """
     import apt_pkg
+
     apt_pkg.init()
 
     try:
         sources = apt_pkg.SourceRecords()
     except apt_pkg.Error as e:
-        if e.args[0] == (
-                'E:You must put some \'deb-src\' URIs in your sources.list'):
+        if e.args[0] == ("E:You must put some 'deb-src' URIs in your sources.list"):
             raise NoAptSources()
         raise
 
@@ -137,9 +135,9 @@ def convert_debian_vcs_url(vcs_type: str, vcs_url: str) -> str:
     try:
         return converters[vcs_type](vcs_url)
     except KeyError:
-        raise ValueError('unknown vcs %s' % vcs_type)
+        raise ValueError("unknown vcs %s" % vcs_type)
     except InvalidURL as e:
-        raise ValueError('invalid URL: %s' % e)
+        raise ValueError("invalid URL: %s" % e)
 
 
 def open_packaging_branch(location, possible_transports=None, vcs_type=None):
@@ -147,74 +145,62 @@ def open_packaging_branch(location, possible_transports=None, vcs_type=None):
 
     location can either be a package name or a full URL
     """
-    if '/' not in location and ':' not in location:
+    if "/" not in location and ":" not in location:
         pkg_source = apt_get_source_package(location)
         try:
             (vcs_type, vcs_url) = source_package_vcs(pkg_source)
         except KeyError:
-            raise Exception(
-                'Package %s does not have any VCS information' % location)
+            raise Exception("Package %s does not have any VCS information" % location)
         (url, branch_name, subpath) = split_vcs_url(vcs_url)
     else:
         url, params = urlutils.split_segment_parameters(location)
-        branch_name = params.get('branch')
-        subpath = ''
+        branch_name = params.get("branch")
+        subpath = ""
     probers = select_probers(vcs_type)
     branch = open_branch(
-        url, possible_transports=possible_transports, probers=probers,
-        name=branch_name)
-    return branch, subpath or ''
+        url, possible_transports=possible_transports, probers=probers, name=branch_name
+    )
+    return branch, subpath or ""
 
 
 def pick_additional_colocated_branches(main_branch):
     ret = ["pristine-tar", "pristine-lfs", "upstream"]
-    ret.append('patch-queue/' + main_branch.name)
-    if main_branch.name.startswith('debian/'):
-        parts = main_branch.name.split('/')
-        parts[0] = 'upstream'
-        ret.append('/'.join(parts))
+    ret.append("patch-queue/" + main_branch.name)
+    if main_branch.name.startswith("debian/"):
+        parts = main_branch.name.split("/")
+        parts[0] = "upstream"
+        ret.append("/".join(parts))
     return ret
 
 
 class Workspace(_mod_proposal.Workspace):
-
     def __init__(self, main_branch: Branch, *args, **kwargs) -> None:
         if isinstance(main_branch.repository, GitRepository):
-            kwargs['additional_colocated_branches'] = (
-                kwargs.get('additional_colocated_branches', []) +
-                pick_additional_colocated_branches(main_branch))
+            kwargs["additional_colocated_branches"] = kwargs.get(
+                "additional_colocated_branches", []
+            ) + pick_additional_colocated_branches(main_branch)
         super(Workspace, self).__init__(main_branch, *args, **kwargs)
 
-    def build(self, builder: Optional[str] = None,
-              result_dir: Optional[str] = None, subpath: str = '') -> None:
-        return build(tree=self.local_tree, subpath=subpath, builder=builder,
-                     result_dir=result_dir)
-
-
-def debcommit(tree, committer=None, subpath='', paths=None):
-    message = changelog_commit_message(
-        tree, tree.basis_tree(),
-        path=os.path.join(subpath, 'debian/changelog'))
-    if paths:
-        specific_files = [os.path.join(subpath, p) for p in paths]
-    elif subpath:
-        specific_files = [subpath]
-    else:
-        specific_files = None
-    tree.commit(
-        committer=committer,
-        message=message,
-        specific_files=specific_files)
+    def build(
+        self,
+        builder: Optional[str] = None,
+        result_dir: Optional[str] = None,
+        subpath: str = "",
+    ) -> None:
+        return build(
+            tree=self.local_tree,
+            subpath=subpath,
+            builder=builder,
+            result_dir=result_dir,
+        )
 
 
 class UnsupportedVCSProber(Prober):
-
     def __init__(self, vcs_type):
         self.vcs_type = vcs_type
 
     def __eq__(self, other):
-        return (isinstance(other, type(self)) and
-                other.vcs_type == self.vcs_type)
+        return isinstance(other, type(self)) and other.vcs_type == self.vcs_type
 
     def __call__(self):
         # The prober expects to be registered as a class.
@@ -225,8 +211,8 @@ class UnsupportedVCSProber(Prober):
 
     def probe_transport(self, transport):
         raise UnsupportedFormatError(
-            'This VCS %s is not currently supported.' %
-            self.vcs_type)
+            "This VCS %s is not currently supported." % self.vcs_type
+        )
 
     @classmethod
     def known_formats(klass):
@@ -234,8 +220,8 @@ class UnsupportedVCSProber(Prober):
 
 
 prober_registry = {
-    'bzr': RemoteBzrProber,
-    'git': RemoteGitProber,
+    "bzr": RemoteBzrProber,
+    "git": RemoteGitProber,
 }
 
 try:
@@ -243,35 +229,35 @@ try:
 except ImportError:
     pass
 else:
-    prober_registry['fossil'] = RemoteFossilProber
+    prober_registry["fossil"] = RemoteFossilProber
 
 try:
     from breezy.plugins.svn import SvnRepositoryProber
 except ImportError:
     pass
 else:
-    prober_registry['svn'] = SvnRepositoryProber
+    prober_registry["svn"] = SvnRepositoryProber
 
 try:
     from breezy.plugins.hg import SmartHgProber
 except ImportError:
     pass
 else:
-    prober_registry['hg'] = SmartHgProber
+    prober_registry["hg"] = SmartHgProber
 
 try:
     from breezy.plugins.darcs import DarcsProber
 except ImportError:
     pass
 else:
-    prober_registry['darcs'] = DarcsProber
+    prober_registry["darcs"] = DarcsProber
 
 try:
     from breezy.plugins.cvs import CVSProber
 except ImportError:
     pass
 else:
-    prober_registry['cvs'] = CVSProber
+    prober_registry["cvs"] = CVSProber
 
 
 def select_probers(vcs_type=None):
@@ -294,35 +280,32 @@ def select_preferred_probers(vcs_type: Optional[str] = None) -> List[Prober]:
 
 
 def changelog_add_line(
-        tree: WorkingTree,
-        subpath: str,
-        line: str,
-        email: Optional[str] = None) -> None:
+    tree: WorkingTree, subpath: str, line: str, email: Optional[str] = None
+) -> None:
     env = {}
     if email:
-        env['DEBEMAIL'] = email
-    subprocess.check_call(
-        ['dch', '--', line], cwd=tree.abspath(subpath), env=env)
+        env["DEBEMAIL"] = email
+    subprocess.check_call(["dch", "--", line], cwd=tree.abspath(subpath), env=env)
 
 
 def is_debcargo_package(tree: Tree, subpath: str) -> bool:
-    debian_path = os.path.join(subpath, 'debian')
+    debian_path = os.path.join(subpath, "debian")
     if tree.has_filename(debian_path):
         return False
-    control_path = os.path.join(subpath, 'debcargo.toml')
+    control_path = os.path.join(subpath, "debcargo.toml")
     if tree.has_filename(control_path):
         return True
     return False
 
 
 def control_files_in_root(tree: Tree, subpath: str) -> bool:
-    debian_path = os.path.join(subpath, 'debian')
+    debian_path = os.path.join(subpath, "debian")
     if tree.has_filename(debian_path):
         return False
-    control_path = os.path.join(subpath, 'control')
+    control_path = os.path.join(subpath, "control")
     if tree.has_filename(control_path):
         return True
-    if tree.has_filename(control_path + '.in'):
+    if tree.has_filename(control_path + ".in"):
         return True
     return False
 
@@ -336,8 +319,7 @@ def control_file_present(tree: Tree, subpath: str) -> bool:
     Returns:
       whether control file is present
     """
-    for name in ['debian/control', 'debian/control.in', 'control',
-                 'control.in']:
+    for name in ["debian/control", "debian/control.in", "control", "control.in"]:
         name = os.path.join(subpath, name)
         if tree.has_filename(name):
             return True
